Crate ppaass_v3_protocol

Crate ppaass_v3_protocol 

Structs

HandshakeRequest
The handshake message between agent and proxy. When the tcp connection created between agent and proxy, the handshake will happen as the first message used to communicate the authentication information and exchange the encryption key.
HandshakeResponse
The handshake response, exchange the proxy side encryption to agent
HeartbeatRequest
HeartbeatResponse
TunnelInitRequest
The tcp destination initialize message used to initialize the destination

Enums

Encryption
The encryption in Handshake message used to switch the encryption key
ProtocolError
TunnelControlRequest
TunnelControlResponse
TunnelInitFailureReason
The failure reason for destination init
TunnelInitResponse
The tcp destination initialize message used to initialize the destination
UnifiedAddress
The unified address which can support both IP V4, IP V6 and Domain